## ------------------------------------------------------------------------
## Find festival headers
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_FESTIVAL_H,
[
AC_MSG_CHECKING([for festival.h])

AC_CACHE_VAL(ac_cv_have_festival_h,
ac_festival_dirs="../festival/src/include festival/src/include"
ac_speech_tool_dirs="../speech_tools/include speech_tools/include"

ac_have_festival_h="no"
ac_festival_dir=""
ac_have_ets_h="no"
ac_ets_dir=""
ac_cv_have_festival_h="have_festival=no"

FESTIVAL_LIBS=""
FESTIVAL_LDFLAGS=""

for dir in $ac_festival_dirs; do
  if test -f "$dir/festival.h"; then
    ac_have_festival_h="yes"
    ac_festival_dir=$dir
    break
  fi
done
if test x$ac_have_festival_h = xyes; then
  for dir in $ac_speech_tool_dirs; do
    if test -f "$dir/EST.h"; then
      ac_have_ets_h="yes"
      ac_ets_dir=$dir
      break
    fi
  done  
  if test x$ac_have_ets_h = xyes; then
    ac_cv_have_festival_h="have_festival=yes"
  fi
fi
)

eval "$ac_cv_have_festival_h"

if test x$have_festival = xyes; then
  ac_cv_have_festival_h="have_festival=yes \
    ac_festival_dir=$ac_festival_dir \
    ac_ets_dir=$ac_ets_dir"

  CXXFLAGS="$CXXFLAGS -I`pwd`/$ac_festival_dir -I`pwd`/$ac_ets_dir"
  AC_DEFINE(HAVE_FESTIVAL_H)
  FESTIVAL_LIBS="-lFestival -lestools -lestbase -leststring -lncurses"
  FESTIVAL_LDFLAGS="-L`pwd`/${ac_festival_dir}/../lib -L`pwd`/${ac_ets_dir}/../lib"
fi

AC_SUBST(FESTIVAL_LIBS)
AC_SUBST(FESTIVAL_LDFLAGS)

AC_MSG_RESULT($have_festival)
])


## KDE/acinclude.m4 (Macros for autoconf) (modified)
##
## (C) 1997 Janos Farkas
## (C) 1997 Stephan Kulow

## ------------------------------------------------------------------------
## Find a file (or one of more files in a list of dirs)
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_FIND_FILE,
[
$3=NO
for i in $2;
do
  for j in $1;
  do
    if test -r "$i/$j"; then
      $3=$i
      break 2
    fi
  done
done
])

## ------------------------------------------------------------------------
## Internal macros to find if we don't need extra flags to find these
## This is not yet used
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT_DIRECT,
[if test "$ac_qt_includes" = NO; then
AC_TRY_CPP([#include <qtstream.h>],
[
ac_qt_includes=
],[
])
fi
])

## ------------------------------------------------------------------------
## Find the meta object compiler in the PATH, in $QTDIR/bin, and some
## more usual places
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT_MOC,
[
AC_PATH_PROG(MOC, moc, /usr/bin/moc,
 $PATH:/usr/bin:/usr/X11R6/bin:$QTDIR/bin:/usr/lib/qt/bin:/usr/local/qt/bin)
])

## ------------------------------------------------------------------------
## Try to find the QT headers and libraries.
## $(QT_LDLFLAGS) will be -Lqtliblocation (if needed)
## and $(QT_INCLUDES) will be -Iqthdrlocation (if needed)
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT,
[
AC_REQUIRE_CPP()

AC_MSG_CHECKING([for qt>=1.30])
ac_qt_includes=NO ac_qt_libraries=NO
qt_libraries=""
qt_includes=""
AC_ARG_WITH(qt-dir,
    [  --with-qt-dir           where the root of qt is installed ],
    [  ac_qt_includes="$withval"/include
       ac_qt_libraries="$withval"/lib
    ])

AC_ARG_WITH(qt-includes,
    [  --with-qt-includes      where the qt includes are. ],
    [  
       ac_qt_includes="$withval"
    ])
    
AC_ARG_WITH(qt-libraries,
    [  --with-qt-libraries     where the qt library is installed.],
    [  ac_qt_libraries="$withval"
    ])

if test "$ac_qt_includes" = NO || test "$ac_qt_libraries" = NO; then

AC_CACHE_VAL(ac_cv_have_qt,
AC_PATH_QT_DIRECT
[#try to guess qt locations

qt_incdirs="/usr/lib/qt/include /usr/local/qt/include /usr/include/qt /usr/include /usr/X11R6/include/X11/qt $QTINC"
test -n "$QTDIR" && qt_incdirs="$QTDIR/include $QTDIR $qt_incdirs"
AC_FIND_FILE(qmovie.h, $qt_incdirs, qt_incdir)
ac_qt_includes=$qt_incdir

qt_libdirs="/usr/lib/qt/lib /usr/local/qt/lib /usr/lib/qt /usr/lib $QTLIB"
test -n "$QTDIR" && qt_libdirs="$QTDIR/lib $QTDIR $qt_libdirs"
AC_FIND_FILE(libqt.so libqt.so.1 libqt.a libqt.sl, $qt_libdirs, qt_libdir)
ac_qt_libraries=$qt_libdir

ac_cxxflags_safe=$CXXFLAGS
ac_ldflags_safe=$LDFLAGS
ac_libs_safe=$LIBS
CXXFLAGS="$CXXFLAGS -I$qt_incdir"
LDFLAGS="-L$qt_libdir"
LIBS="-lqt"

AC_LANG_CPLUSPLUS
cat > conftest.$ac_ext <<EOF
#include "confdefs.h"
#include <qmovie.h>
int main() {
  QMovie m;
  m.setSpeed(20);
  return 0;
};
EOF

if AC_TRY_EVAL(ac_link) && test -s conftest; then
  rm -f conftest*
else
  echo "configure: failed program was:" >&AC_FD_CC
  cat conftest.$ac_ext >&AC_FD_CC
  ac_qt_libraries="NO"
fi
rm -f conftest*
CXXFLAGS=$ac_cxxflags_safe
LDFLAGS=$ac_ldflags_safe
LIBS=$ac_libs_safe

if test "$ac_qt_includes" = NO || test "$ac_qt_libraries" = NO; then
  ac_cv_have_qt="have_qt=no"
  ac_qt_notfound=""
  if test "$ac_qt_includes" = NO; then
    if test "$ac_qt_libraries" = NO; then
      ac_qt_notfound="(headers and libraries)";
    else
      ac_qt_notfound="(headers)";
    fi
  else
    ac_qt_notfound="(libraries)";
  fi
  AC_MSG_RESULT(missing)
  AC_MSG_ERROR([qt $ac_qt_notfound not found. Please check your installation! ]);
else
  have_qt="yes"
fi
])
else
  have_qt="yes"
fi

eval "$ac_cv_have_qt"

if test "$have_qt" != yes; then
  AC_MSG_RESULT(missing);
else
  ac_cv_have_qt="have_qt=yes \
    ac_qt_includes=$ac_qt_includes ac_qt_libraries=$ac_qt_libraries"
  AC_MSG_RESULT([libraries $ac_qt_libraries, headers $ac_qt_includes])
  
  qt_libraries=$ac_qt_libraries
  qt_includes=$ac_qt_includes
fi
AC_SUBST(qt_libraries)
AC_SUBST(qt_includes)

QT_INCLUDES="-I$qt_includes"

QT_LDFLAGS="-L$qt_libraries"

AC_SUBST(QT_INCLUDES)
AC_SUBST(QT_LDFLAGS)
AC_PATH_QT_MOC
])
