/* 	$Id: xirw.cpp,v 1.13 2001/02/04 21:47:34 columbus Exp $	 */

/*
  
  xirw -  X-application showing decoded buttons from lircd
  
  Copyright (C) 1998 Christoph Bartelmus (lirc@bartelmus.de)
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  
*/

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <ctype.h>
#include <getopt.h>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/time.h>

#include <iostream.h>

#ifdef HAVE_FESTIVAL_H
#undef HAVE_CONFIG_H
#include <festival.h>
#endif

#include "xirw.h"

#include "xirw.moc"

char *progname;

Xirw::Xirw(QWidget * parent=0, const char * name=0, WFlags f=0 )
	: QWidget(parent,name,f)
{
	struct sockaddr_un addr;
	int flags;

	while(1)
	{
		int c;
		static struct option long_options[] =
		{
			{"help",no_argument,NULL,'h'},
			{"version",no_argument,NULL,'v'},
			{0, 0, 0, 0}
		};

		c = getopt_long(qApp->argc(),qApp->argv(),"hv",long_options,NULL);
		if(c==-1)
			break;
		switch (c)
		{
		case 'h':
			cout << "Usage: " << progname << " [OPTIONS]" << endl;
			cout << "\t -h --help\t\t\tdisplay this message" << endl;
			cout << "\t -v --version\t\t\tdisplay version" << endl;
			exit(EXIT_SUCCESS);
		case 'v':
			cout << "xirw " << VERSION << endl;
			exit(EXIT_SUCCESS);
		default:
			cerr << progname << ": unknown parameter " << (char) c << endl;
			exit(EXIT_FAILURE);
		}
	}
	if (optind < qApp->argc())
	{
		cerr << progname << ": too many arguments" << endl;
		exit(EXIT_FAILURE);
	}


#ifdef HAVE_FESTIVAL_H
	festival_initialize(1,210000);
#endif
	sock=lirc_init("xirw",1);
	if(sock==-1) exit(EXIT_FAILURE);

	if(lirc_readconfig(NULL,&config,NULL)!=0) exit(EXIT_FAILURE);

	label=new QLabel(this);
	label->setAutoResize(true);
	label->setText("---");

	off=on=label->palette();

	const QColorGroup *cg,*ncg;
	cg=&on.normal();
	ncg=new QColorGroup(cg->foreground(),cg->background(),cg->light(),
			    cg->dark(),cg->mid(),QColor("green"),cg->base());
	on.setNormal(*ncg);
	delete ncg;
	
	fcntl(sock,F_SETOWN,getpid());
	flags=fcntl(sock,F_GETFL,0);
	if(flags!=-1)
	{
		fcntl(sock,F_SETFL,flags|O_NONBLOCK);
	}
	sn=new QSocketNotifier(sock,QSocketNotifier::Read,0);
	connect(sn,SIGNAL(activated(int)),
		this,SLOT(update()));
}

Xirw::~Xirw()
{
	if(config) lirc_freeconfig(config);
	if(label) delete label;
	delete sn;
	lirc_deinit();
}

void Xirw::update(void)
{
	int ret;
	char *code;
	char *c;
	char buffer[200];
	size_t l;

	while((ret=lirc_nextcode(&code))==0 && code!=NULL)
	{
		while((ret=lirc_code2char(config,code,&c))==0 && c!=NULL)
		{
			killTimers();
#ifdef HAVE_FESTIVAL_H
			festival_say_text(c);
#endif
			strncpy(buffer,c,80);
			l=strlen(buffer);
			strcat(buffer+l,"\nMode: ");
			l+=7;
			
			if(config->current_mode)
			{
				strncat(buffer+l,config->current_mode,80-7);
			}
			else
			{
				strcat(buffer+l,"---");
			}

			label->setText(buffer);

			if(label->width()>width())
			{
				setFixedWidth(label->width());
			}
			if(label->height()>height())
			{
				setFixedHeight(label->height());
			}
			label->setPalette(on);
			startTimer(200);
		}
		free(code);
		if(ret==-1) break;
	}
	if(ret==-1)
	{
		// something went badly wrong
		QApplication::exit(EXIT_FAILURE);		
		return;
	}
#if 0
	ssize_t len;
	static char buffer[PACKET_SIZE+1]="";
	static int end_len=0;
	int rep;
	char button[PACKET_SIZE+1];;
	char remote[PACKET_SIZE+1];
	char *end;


	len=0;
	do
	{
		if(strchr(buffer,'\n')==NULL)
		{
			len=read(sock,buffer+end_len,PACKET_SIZE-end_len);
		}
		if(len==-1)
		{
			if(errno==EAGAIN) break;
			cerr << progname << ": failed to read from socket" << endl;
			exit(EXIT_FAILURE);
		}
		buffer[len+end_len]=0;
		if(sscanf(buffer,"%*llx %x %s %s\n",&rep,button,remote)==3)
		{
			end=strchr(buffer,'\n')+1;
			end_len=strlen(end);
			memmove(buffer,end,end_len+1);
			killTimers();
			sprintf(button,"%s\n%s\n%d",button,remote,rep);
			label->setText(button);
			if(label->width()>width())
			{
				setFixedWidth(label->width());
			}
			if(label->height()>height())
			{
				setFixedHeight(label->height());
			}
			label->setPalette(on);
			startTimer(200);
		}
	}
	while(len!=0);
#endif
}

void Xirw::keyPressEvent(QKeyEvent *e)
{
	switch(tolower(e->ascii()))
	{
        case 'q':
		QApplication::exit(EXIT_SUCCESS);
		break;
	default:
		e->ignore();
	}
}

void Xirw::timerEvent(QTimerEvent *e)
{
	label->setPalette(off);
	label->update();
	killTimers();
}

int main(int argc,char **argv)
{
	QFont font("courier",48,QFont::Bold);
	font.setDefaultFont(font);
	QApplication a(argc,argv);
	progname=argv[0];
	Xirw xirw;

	a.setMainWidget(&xirw);
	xirw.show();

	return a.exec();
}
